Test WaitForNot

First test waitForNotValue

Test WaitForValueNot
open | ../tests/html/test_async_event.html |
assertValue | theField | oldValue
click | theButton |
assertValue | theField | oldValue
waitForNotValue | theField | regexp:oldValu[aei]
verifyValue | theField | newValue

Now test waitForTextNot

assertText | theSpan | Some text
click | theSpanButton |
assertText | theSpan | Some text
waitForNotText | theSpan | regexp:Some te[xyz]t
verifyText | theSpan | Some new text